export declare type TeemoApiProxy<TSpec extends EndpointsSpec> = {
    [TEndpoint in Exclude<keyof TSpec, "base">]: {
        [TMethod in keyof TSpec[TEndpoint]]: (region: ReqRegion<TSpec[TEndpoint][TMethod]>, ...kwargs: ReqArgsTuple<TSpec[TEndpoint][TMethod]>) => ReqReturn<TSpec[TEndpoint][TMethod]>;
    };
} & {
    base: TeemoApi<TSpec>;
};
export declare class TeemoApi<TSpec extends EndpointsSpec> {
    /** The config for this TeemoApi. */
    readonly config: Config<TSpec>;
    /** The requesters created by this TeemoApi, keyed uniquely per api key and region. */
    private readonly _requesters;
    static createRiotApi(apiKey: string | RiotApiKeys): TeemoApi<typeof RiotApiConfig.endpoints>;
    constructor(config: Config<TSpec>);
    proxy(): TeemoApiProxy<TSpec>;
    req<TEndpoint extends keyof TSpec, TMethod extends keyof TSpec[TEndpoint]>(endpoint: TEndpoint, method: TMethod, region: ReqRegion<TSpec[TEndpoint][TMethod]>, ...[kwargs, ..._]: ReqArgsTuple<TSpec[TEndpoint][TMethod]>): ReqReturn<TSpec[TEndpoint][TMethod]>;
    reqInternal(rateLimitId: string, methodId: string, url: string, fetchConfig: import("node-fetch").RequestInit): any;
    setDistFactor(factor: number): void;
}
export declare enum Region {
    BR1 = 1,
    EUN1 = 2,
    EUW1 = 3,
    JP1 = 4,
    KR = 5,
    LA1 = 6,
    LA2 = 7,
    NA1 = 8,
    OC1 = 9,
    TR1 = 10,
    RU = 11,
    AMERICAS = 16,
    ASIA = 17,
    EUROPE = 18,
    SEA = 19
}
export declare type RegionRoute = Region.AMERICAS | Region.EUROPE | Region.ASIA | Region.SEA;
export declare namespace Region {
    function getRoute(region: Region): RegionRoute;
}
/** 32-bit integer (signed). */
export declare type int = number;
/**
 * 64-bit integer (signed).
 * NOTE: Precision loss for numbers over Number.MAX_SAFE_INTEGER (~9
 * quadrilion).
 */
export declare type long = number;
/** 32-bit single-precision float. */
export declare type float = number;
/** 64-bit double-precision float. */
export declare type double = number;
/** Header information for an application or method rate limit. */
interface RateLimitType {
    readonly name: string;
    readonly headerLimit: string;
    readonly headerCount: string;
}
/** Token bucket configuration parameters. */
interface TokenBucketConfig {
    readonly distFactor?: number;
    readonly bins?: number;
    readonly binFactor?: number;
    readonly overhead?: number;
}
/**
 * Default token bucket initialization parameters before rate limits are known.
 */
interface InitialTokenBucketConfig extends TokenBucketConfig {
    readonly timespan: number;
    readonly limit: number;
}
/** Dictionary of API keys including a 'default' key. */
interface ApiKeys {
    default: string;
    [apiKeyName: string]: string | undefined;
}
/** A configuration needed to instantiate a RiotApi. */
interface Config<TSpec extends EndpointsSpec> {
    distFactor: number;
    readonly apiKeys: ApiKeys;
    readonly origin: string;
    readonly maxConcurrent: number;
    readonly defaultBuckets: InitialTokenBucketConfig[];
    readonly bucketsConfig: TokenBucketConfig;
    readonly rateLimitTypeApplication: RateLimitType;
    readonly rateLimitTypeMethod: RateLimitType;
    readonly headerRetryAfter: string;
    readonly headerLimitType: string;
    readonly endpoints: TSpec;
}
/** Listing of endpoints. */
export declare type EndpointsSpec = {
    readonly [endpoint: string]: {
        readonly [method: string]: ReqSpec<any, any, any, any, any>;
    };
};
/** Named query parameters. */
export declare type NamedParams = {
    [argName: string]: unknown;
};
/** Ordered path parameters. */
export declare type OrderedParams = {
    [argIdx: number]: unknown;
};
/**
 * ReqSpec with optional type parameters for annotating the input parameters
 * and return type.
 */
export declare type ReqSpec<_TReturn, _TPlatforms extends string | Region, _TPath extends OrderedParams | NamedParams, _TQuery extends NamedParams, _TBody> = {
    readonly path: string;
    readonly method?: import("node-fetch").RequestInit['method'];
    readonly apiKeyName?: string;
};
/** Utility type which extracts Promise<TReturn> from a ReqSpec. */
export declare type ReqReturn<TReqSpec extends ReqSpec<any, any, any, any, any>> = TReqSpec extends ReqSpec<infer TReturn, any, any, any, any> ? Promise<TReturn> : Promise<unknown>;
/** Utility type which extracts a Region type union from a ReqSpec. */
export declare type ReqRegion<TReqSpec extends ReqSpec<any, any, any, any, any>> = (TReqSpec extends ReqSpec<any, infer TPlatforms, any, any, any> ? TPlatforms extends keyof typeof Region ? (typeof Region)[TPlatforms] : TPlatforms : Region) | string;
/**
 * Utility type which allows top-level list fields to be replaced by single
 * non-list values of the corresponding type.
 */
export declare type AllowSingleItemLists<T> = {
    [K in keyof T]: T[K] extends Array<infer TItem> ? T[K] | TItem : T[K];
};
/**
 * Utility type which creates a { path, query, body } kwargs type from a
 * ReqSpec. Fields are made optional if they are not required.
 */
export declare type ReqArgs<TReqSpec extends ReqSpec<any, any, any, any, any>> = TReqSpec extends ReqSpec<any, any, infer TPath, infer TQuery, infer TBody> ? (({} extends TPath ? {
    path?: TPath | null;
} : {
    path: TPath;
}) & ({} extends TQuery ? {
    query?: AllowSingleItemLists<TQuery> | null;
} : {
    query: AllowSingleItemLists<TQuery>;
}) & (undefined extends TBody ? {
    body?: TBody;
} : {
    body: TBody;
})) : {
    path?: OrderedParams | NamedParams | null;
    query?: NamedParams | null;
    body?: any;
};
/**
 * ReqArgs but as a tuple so optional paramters can be spread.
 * HACK: see https://github.com/microsoft/TypeScript/issues/29131
 */
export declare type ReqArgsTuple<TReqSpec extends ReqSpec<any, any, any, any, any>> = {} extends ReqArgs<TReqSpec> ? [ReqArgs<TReqSpec>?] : [ReqArgs<TReqSpec>];
export declare const RiotApiConfig: {
    apiKeys: undefined;
    origin: string;
    defaultBuckets: {
        timespan: number;
        limit: number;
        bins: number;
        binFactor: number;
        overhead: number;
    }[];
    rateLimitTypeApplication: {
        name: string;
        headerLimit: string;
        headerCount: string;
    };
    rateLimitTypeMethod: {
        name: string;
        headerLimit: string;
        headerCount: string;
    };
    maxConcurrent: number;
    distFactor: number;
    headerLimitType: string;
    headerRetryAfter: string;
    bucketsConfig: {};
    endpoints: {
        championMasteryV4: {
            /**
             * Get all champion mastery entries sorted by number of champion points descending,
             */
            getAllChampionMasteries: ReqSpec<championMasteryV4.ChampionMasteryDTO[], "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedSummonerId: string;
            }, {}, undefined>;
            /**
             * Get a champion mastery by player ID and champion ID.
             */
            getChampionMastery: ReqSpec<championMasteryV4.ChampionMasteryDTO | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {
                encryptedSummonerId: string;
                championId: long;
            } | [string, number], {}, undefined>;
            /**
             * Get a player's total champion mastery score, which is the sum of individual champion mastery levels.
             */
            getChampionMasteryScore: ReqSpec<number, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedSummonerId: string;
            }, {}, undefined>;
        };
        championV3: {
            /**
             * Returns champion rotations, including free-to-play and low-level free-to-play rotations (REST)
             */
            getChampionInfo: ReqSpec<championV3.ChampionInfo, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {} | [], {}, undefined>;
        };
        clashV1: {
            /**
             * Get players by summoner ID.
             * ## Implementation Notes
             * This endpoint returns a list of active Clash players for a given summoner ID. If a summoner registers for multiple tournaments at the same time (e.g., Saturday and Sunday) then both registrations would appear in this list.
             */
            getPlayersBySummoner: ReqSpec<clashV1.PlayerDto[], "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                summonerId: string;
            }, {}, undefined>;
            /**
             * Get team by ID.
             */
            getTeamById: ReqSpec<clashV1.TeamDto | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                teamId: string;
            }, {}, undefined>;
            /**
             * Get all active or upcoming tournaments.
             */
            getTournaments: ReqSpec<clashV1.TournamentDto[], "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {} | [], {}, undefined>;
            /**
             * Get tournament by team ID.
             */
            getTournamentByTeam: ReqSpec<clashV1.TournamentDto | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                teamId: string;
            }, {}, undefined>;
            /**
             * Get tournament by ID.
             */
            getTournamentById: ReqSpec<clashV1.TournamentDto | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {
                tournamentId: int;
            } | [number], {}, undefined>;
        };
        leagueExpV4: {
            /**
             * Get all the league entries.
             */
            getLeagueEntries: ReqSpec<leagueExpV4.LeagueEntryDTO[], "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {
                queue: "RANKED_SOLO_5x5" | "RANKED_TFT" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT";
                tier: "CHALLENGER" | "GRANDMASTER" | "MASTER" | "DIAMOND" | "PLATINUM" | "GOLD" | "SILVER" | "BRONZE" | "IRON";
                division: "I" | "II" | "III" | "IV";
            } | ["RANKED_SOLO_5x5" | "RANKED_TFT" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT", "CHALLENGER" | "GRANDMASTER" | "MASTER" | "DIAMOND" | "PLATINUM" | "GOLD" | "SILVER" | "BRONZE" | "IRON", "I" | "II" | "III" | "IV"], {
                page?: number | null | undefined;
            }, undefined>;
        };
        leagueV4: {
            /**
             * Get the challenger league for given queue.
             */
            getChallengerLeague: ReqSpec<leagueV4.LeagueListDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {
                queue: "RANKED_SOLO_5x5" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT";
            } | ["RANKED_SOLO_5x5" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT"], {}, undefined>;
            /**
             * Get league entries in all queues for a given summoner ID.
             */
            getLeagueEntriesForSummoner: ReqSpec<leagueV4.LeagueEntryDTO[], "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedSummonerId: string;
            }, {}, undefined>;
            /**
             * Get all the league entries.
             */
            getLeagueEntries: ReqSpec<leagueV4.LeagueEntryDTO[], "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {
                queue: "RANKED_SOLO_5x5" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT";
                tier: "DIAMOND" | "PLATINUM" | "GOLD" | "SILVER" | "BRONZE" | "IRON";
                division: "I" | "II" | "III" | "IV";
            } | ["RANKED_SOLO_5x5" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT", "DIAMOND" | "PLATINUM" | "GOLD" | "SILVER" | "BRONZE" | "IRON", "I" | "II" | "III" | "IV"], {
                page?: number | null | undefined;
            }, undefined>;
            /**
             * Get the grandmaster league of a specific queue.
             */
            getGrandmasterLeague: ReqSpec<leagueV4.LeagueListDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", ["RANKED_SOLO_5x5" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT"] | {
                queue: "RANKED_SOLO_5x5" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT";
            }, {}, undefined>;
            /**
             * Get league with given ID, including inactive entries.
             */
            getLeagueById: ReqSpec<leagueV4.LeagueListDTO | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                leagueId: string;
            }, {}, undefined>;
            /**
             * Get the master league for given queue.
             */
            getMasterLeague: ReqSpec<leagueV4.LeagueListDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", ["RANKED_SOLO_5x5" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT"] | {
                queue: "RANKED_SOLO_5x5" | "RANKED_FLEX_SR" | "RANKED_FLEX_TT";
            }, {}, undefined>;
        };
        lolStatusV3: {
            /**
             * Get League of Legends status for the given shard.
             * ## Rate Limit Notes
             * Requests to this API are not counted against the application Rate Limits.
             */
            getShardData: ReqSpec<lolStatusV3.ShardStatus, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU" | "PBE1", {} | [], {}, undefined>;
        };
        lorRankedV1: {
            /**
             * Get the players in Master tier.
             */
            getLeaderboards: ReqSpec<lorRankedV1.LeaderboardDto, "AMERICAS" | "ASIA" | "EUROPE" | "SEA", {} | [], {}, undefined>;
        };
        matchV4: {
            /**
             * Get match IDs by tournament code.
             */
            getMatchIdsByTournamentCode: ReqSpec<number[], "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                tournamentCode: string;
            }, {}, undefined>;
            /**
             * Get match by match ID.
             */
            getMatch: ReqSpec<matchV4.MatchDto | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [number] | {
                matchId: long;
            }, {}, undefined>;
            /**
             * Get match by match ID and tournament code.
             */
            getMatchByTournamentCode: ReqSpec<matchV4.MatchDto, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {
                matchId: long;
                tournamentCode: string;
            } | [number, string], {}, undefined>;
            /**
             * Get matchlist for games played on given account ID and platform ID and filtered using given filter parameters, if any.
             * ## Implementation Notes
             * A number of optional parameters are provided for filtering. It is up to the caller to ensure that the combination of filter parameters provided is valid for the requested account, otherwise, no matches may be returned.
             *
             * If beginIndex is specified, but not endIndex, then endIndex defaults to beginIndex+100. If endIndex is specified, but not beginIndex, then beginIndex defaults to 0. If both are specified, then endIndex must be greater than beginIndex. The maximum range allowed is 100, otherwise a 400 error code is returned.
             *
             * If beginTime is specified, but not endTime, then endTime defaults to the the current unix timestamp in milliseconds (the maximum time range limitation is not observed in this specific case). If endTime is specified, but not beginTime, then beginTime defaults to the start of the account's match history returning a 400 due to the maximum time range limitation. If both are specified, then endTime should be greater than beginTime. The maximum time range allowed is one week, otherwise a 400 error code is returned.
             */
            getMatchlist: ReqSpec<matchV4.MatchlistDto | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedAccountId: string;
            }, {
                champion?: number[] | null | undefined;
                queue?: number[] | null | undefined;
                season?: number[] | null | undefined;
                endTime?: number | null | undefined;
                beginTime?: number | null | undefined;
                endIndex?: number | null | undefined;
                beginIndex?: number | null | undefined;
            }, undefined>;
            /**
             * Get match timeline by match ID.
             * ## Implementation Notes
             * Not all matches have timeline data.
             */
            getMatchTimeline: ReqSpec<matchV4.MatchTimelineDto | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [number] | {
                matchId: long;
            }, {}, undefined>;
        };
        spectatorV4: {
            /**
             * Get current game information for the given summoner ID.
             */
            getCurrentGameInfoBySummoner: ReqSpec<spectatorV4.CurrentGameInfo | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedSummonerId: string;
            }, {}, undefined>;
            /**
             * Get list of featured games.
             */
            getFeaturedGames: ReqSpec<spectatorV4.FeaturedGames, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {} | [], {}, undefined>;
        };
        summonerV4: {
            /**
             * Get a summoner by account ID.
             */
            getByAccountId: ReqSpec<summonerV4.SummonerDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedAccountId: string;
            }, {}, undefined>;
            /**
             * Get a summoner by summoner name.
             */
            getBySummonerName: ReqSpec<summonerV4.SummonerDTO | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                summonerName: string;
            }, {}, undefined>;
            /**
             * Get a summoner by PUUID.
             */
            getByPUUID: ReqSpec<summonerV4.SummonerDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedPUUID: string;
            }, {}, undefined>;
            /**
             * Get a summoner by summoner ID.
             */
            getBySummonerId: ReqSpec<summonerV4.SummonerDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedSummonerId: string;
            }, {}, undefined>;
        };
        tftLeagueV1: {
            /**
             * Get the challenger league.
             */
            getChallengerLeague: ReqSpec<tftLeagueV1.LeagueListDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {} | [], {}, undefined>;
            /**
             * Get league entries for a given summoner ID.
             */
            getLeagueEntriesForSummoner: ReqSpec<tftLeagueV1.LeagueEntryDTO[], "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedSummonerId: string;
            }, {}, undefined>;
            /**
             * Get all the league entries.
             */
            getLeagueEntries: ReqSpec<tftLeagueV1.LeagueEntryDTO[], "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {
                tier: "DIAMOND" | "PLATINUM" | "GOLD" | "SILVER" | "BRONZE" | "IRON";
                division: "I" | "II" | "III" | "IV";
            } | ["DIAMOND" | "PLATINUM" | "GOLD" | "SILVER" | "BRONZE" | "IRON", "I" | "II" | "III" | "IV"], {
                page?: number | null | undefined;
            }, undefined>;
            /**
             * Get the grandmaster league.
             */
            getGrandmasterLeague: ReqSpec<tftLeagueV1.LeagueListDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {} | [], {}, undefined>;
            /**
             * Get league with given ID, including inactive entries.
             */
            getLeagueById: ReqSpec<tftLeagueV1.LeagueListDTO | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                leagueId: string;
            }, {}, undefined>;
            /**
             * Get the master league.
             */
            getMasterLeague: ReqSpec<tftLeagueV1.LeagueListDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", {} | [], {}, undefined>;
        };
        tftMatchV1: {
            /**
             * Get a list of match ids by PUUID.
             */
            getMatchIdsByPUUID: ReqSpec<string[], "AMERICAS" | "ASIA" | "EUROPE", {
                puuid: String;
            } | [String], {
                count?: number | null | undefined;
            }, undefined>;
            /**
             * Get a match by match id.
             */
            getMatch: ReqSpec<tftMatchV1.MatchDto | null, "AMERICAS" | "ASIA" | "EUROPE", [String] | {
                matchId: String;
            }, {}, undefined>;
        };
        tftSummonerV1: {
            /**
             * Get a summoner by account ID.
             */
            getByAccountId: ReqSpec<tftSummonerV1.SummonerDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedAccountId: string;
            }, {}, undefined>;
            /**
             * Get a summoner by summoner name.
             */
            getBySummonerName: ReqSpec<tftSummonerV1.SummonerDTO | null, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                summonerName: string;
            }, {}, undefined>;
            /**
             * Get a summoner by PUUID.
             */
            getByPUUID: ReqSpec<tftSummonerV1.SummonerDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedPUUID: string;
            }, {}, undefined>;
            /**
             * Get a summoner by summoner ID.
             */
            getBySummonerId: ReqSpec<tftSummonerV1.SummonerDTO, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedSummonerId: string;
            }, {}, undefined>;
        };
        thirdPartyCodeV4: {
            /**
             * Get third party code for a given summoner ID.
             */
            getThirdPartyCodeBySummonerId: ReqSpec<String, "BR1" | "EUN1" | "EUW1" | "JP1" | "KR" | "LA1" | "LA2" | "NA1" | "OC1" | "TR1" | "RU", [string] | {
                encryptedSummonerId: string;
            }, {}, undefined>;
        };
        tournamentStubV4: {
            /**
             * Create a mock tournament code for the given tournament.
             */
            createTournamentCode: ReqSpec<string[], "AMERICAS", {} | [], {
                count?: number | null | undefined;
                tournamentId: long;
            }, tournamentStubV4.TournamentCodeParameters>;
            /**
             * Gets a mock list of lobby events by tournament code.
             */
            getLobbyEventsByCode: ReqSpec<tournamentStubV4.LobbyEventDTOWrapper, "AMERICAS", [string] | {
                tournamentCode: string;
            }, {}, undefined>;
            /**
             * Creates a mock tournament provider and returns its ID.
             * ## Implementation Notes
             * Providers will need to call this endpoint first to register their callback URL and their API key with the tournament system before any other tournament provider endpoints will work.
             */
            registerProviderData: ReqSpec<number, "AMERICAS", {} | [], {}, tournamentStubV4.ProviderRegistrationParameters>;
            /**
             * Creates a mock tournament and returns its ID.
             */
            registerTournament: ReqSpec<number, "AMERICAS", {} | [], {}, tournamentStubV4.TournamentRegistrationParameters>;
        };
        tournamentV4: {
            /**
             * Create a tournament code for the given tournament.
             */
            createTournamentCode: ReqSpec<string[], "AMERICAS", {} | [], {
                count?: number | null | undefined;
                tournamentId: long;
            }, tournamentV4.TournamentCodeParameters>;
            /**
             * Returns the tournament code DTO associated with a tournament code string.
             */
            getTournamentCode: ReqSpec<tournamentV4.TournamentCodeDTO, "AMERICAS", [string] | {
                tournamentCode: string;
            }, {}, undefined>;
            /**
             * Update the pick type, map, spectator type, or allowed summoners for a code.
             */
            updateCode: ReqSpec<void, "AMERICAS", [string] | {
                tournamentCode: string;
            }, {}, tournamentV4.TournamentCodeUpdateParameters>;
            /**
             * Gets a list of lobby events by tournament code.
             */
            getLobbyEventsByCode: ReqSpec<tournamentV4.LobbyEventDTOWrapper, "AMERICAS", [string] | {
                tournamentCode: string;
            }, {}, undefined>;
            /**
             * Creates a tournament provider and returns its ID.
             * ## Implementation Notes
             * Providers will need to call this endpoint first to register their callback URL and their API key with the tournament system before any other tournament provider endpoints will work.
             */
            registerProviderData: ReqSpec<number, "AMERICAS", {} | [], {}, tournamentV4.ProviderRegistrationParameters>;
            /**
             * Creates a tournament and returns its ID.
             */
            registerTournament: ReqSpec<number, "AMERICAS", {} | [], {}, tournamentV4.TournamentRegistrationParameters>;
        };
    };
};
/** API key dictionary for RiotApi endpoints. "default" corresponds to League of Legends endpoints. */
interface RiotApiKeys {
    default: string;
    tft?: string;
    lor?: string;
    tournament?: string;
    [apiKeyName: string]: string | undefined;
}
export declare namespace championMasteryV4 {
    /**
     * ChampionMasteryDTO data object, automatically generated.
     * # Description
     * This object contains single Champion Mastery information for player and champion combination.
     */
    interface ChampionMasteryDTO {
        /** Number of points needed to achieve next level. Zero if player reached maximum champion level for this champion. */
        championPointsUntilNextLevel: long;
        /** Is chest granted for this champion or not in current season. */
        chestGranted: boolean;
        /** Champion ID for this entry. */
        championId: long;
        /** Last time this champion was played by this player - in Unix milliseconds time format. */
        lastPlayTime: long;
        /** Champion level for specified player and champion combination. */
        championLevel: int;
        /** Summoner ID for this entry. (Encrypted) */
        summonerId: string;
        /** Total number of champion points for this player and champion combination - they are used to determine championLevel. */
        championPoints: int;
        /** Number of points earned since current level has been achieved. */
        championPointsSinceLastLevel: long;
        /** The token earned for this champion to levelup. */
        tokensEarned: int;
    }
}
export declare namespace championV3 {
    /**
     * ChampionInfo data object, automatically generated.
     */
    interface ChampionInfo {
        maxNewPlayerLevel: int;
        freeChampionIdsForNewPlayers: int[];
        freeChampionIds: int[];
    }
}
export declare namespace clashV1 {
    /**
     * PlayerDto data object, automatically generated.
     */
    interface PlayerDto {
        summonerId: string;
        teamId: string;
        /** (Legal values:  UNSELECTED,  FILL,  TOP,  JUNGLE,  MIDDLE,  BOTTOM,  UTILITY) */
        position: "UNSELECTED" | "FILL" | "TOP" | "JUNGLE" | "MIDDLE" | "BOTTOM" | "UTILITY";
        /** (Legal values:  CAPTAIN,  MEMBER) */
        role: "CAPTAIN" | "MEMBER";
    }
}
export declare namespace clashV1 {
    /**
     * TeamDto data object, automatically generated.
     */
    interface TeamDto {
        id: string;
        tournamentId: int;
        name: string;
        iconId: int;
        tier: int;
        /** Summoner ID of the team captain. */
        captain: string;
        abbreviation: string;
        /** Team members. */
        players: clashV1.PlayerDto[];
    }
}
export declare namespace clashV1 {
    /**
     * TournamentDto data object, automatically generated.
     */
    interface TournamentDto {
        id: int;
        themeId: int;
        nameKey: string;
        nameKeySecondary: string;
        /** Tournament phase. */
        schedule: clashV1.TournamentPhaseDto[];
    }
}
export declare namespace clashV1 {
    /**
     * TournamentPhaseDto data object, automatically generated.
     */
    interface TournamentPhaseDto {
        id: int;
        registrationTime: long;
        startTime: long;
        cancelled: boolean;
    }
}
export declare namespace leagueExpV4 {
    /**
     * LeagueEntryDTO data object, automatically generated.
     */
    interface LeagueEntryDTO {
        leagueId: string;
        /** Player's summonerId (Encrypted) */
        summonerId: string;
        summonerName: string;
        queueType: string;
        tier: string;
        rank: string;
        leaguePoints: int;
        /** Winning team on Summoners Rift. First placement in Teamfight Tactics. */
        wins: int;
        /** Losing team on Summoners Rift. Second through eighth placement in Teamfight Tactics. */
        losses: int;
        hotStreak: boolean;
        veteran: boolean;
        freshBlood: boolean;
        inactive: boolean;
        miniSeries?: leagueExpV4.MiniSeriesDTO | null;
    }
}
export declare namespace leagueExpV4 {
    /**
     * MiniSeriesDTO data object, automatically generated.
     */
    interface MiniSeriesDTO {
        losses: int;
        progress: string;
        target: int;
        wins: int;
    }
}
export declare namespace leagueV4 {
    /**
     * LeagueListDTO data object, automatically generated.
     */
    interface LeagueListDTO {
        leagueId: string;
        entries: leagueV4.LeagueItemDTO[];
        tier: string;
        name: string;
        queue: string;
    }
}
export declare namespace leagueV4 {
    /**
     * LeagueItemDTO data object, automatically generated.
     */
    interface LeagueItemDTO {
        freshBlood: boolean;
        /** Winning team on Summoners Rift. */
        wins: int;
        summonerName: string;
        miniSeries?: leagueV4.MiniSeriesDTO | null;
        inactive: boolean;
        veteran: boolean;
        hotStreak: boolean;
        rank: string;
        leaguePoints: int;
        /** Losing team on Summoners Rift. */
        losses: int;
        /** Player's encrypted summonerId. */
        summonerId: string;
    }
}
export declare namespace leagueV4 {
    /**
     * MiniSeriesDTO data object, automatically generated.
     */
    interface MiniSeriesDTO {
        losses: int;
        progress: string;
        target: int;
        wins: int;
    }
}
export declare namespace leagueV4 {
    /**
     * LeagueEntryDTO data object, automatically generated.
     */
    interface LeagueEntryDTO {
        leagueId: string;
        /** Player's encrypted summonerId. */
        summonerId: string;
        summonerName: string;
        queueType: string;
        tier: string;
        rank: string;
        leaguePoints: int;
        /** Winning team on Summoners Rift. */
        wins: int;
        /** Losing team on Summoners Rift. */
        losses: int;
        hotStreak: boolean;
        veteran: boolean;
        freshBlood: boolean;
        inactive: boolean;
        miniSeries?: leagueV4.MiniSeriesDTO | null;
    }
}
export declare namespace lolStatusV3 {
    /**
     * ShardStatus data object, automatically generated.
     */
    interface ShardStatus {
        locales: string[];
        hostname: string;
        name: string;
        services: lolStatusV3.Service[];
        slug: string;
        region_tag: string;
    }
}
export declare namespace lolStatusV3 {
    /**
     * Service data object, automatically generated.
     */
    interface Service {
        incidents: lolStatusV3.Incident[];
        name: string;
        slug: string;
        status: string;
    }
}
export declare namespace lolStatusV3 {
    /**
     * Incident data object, automatically generated.
     */
    interface Incident {
        active: boolean;
        created_at: string;
        id: long;
        updates: lolStatusV3.Message[];
    }
}
export declare namespace lolStatusV3 {
    /**
     * Message data object, automatically generated.
     */
    interface Message {
        severity: string;
        updated_at: string;
        author: string;
        translations: lolStatusV3.Translation[];
        created_at: string;
        id: string;
        content: string;
    }
}
export declare namespace lolStatusV3 {
    /**
     * Translation data object, automatically generated.
     */
    interface Translation {
        locale: string;
        content: string;
        heading: string;
    }
}
export declare namespace lorRankedV1 {
    /**
     * LeaderboardDto data object, automatically generated.
     */
    interface LeaderboardDto {
        /** A list of players in Master tier. */
        players: lorRankedV1.PlayerDto[];
    }
}
export declare namespace lorRankedV1 {
    /**
     * PlayerDto data object, automatically generated.
     */
    interface PlayerDto {
        name: string;
        rank: int;
    }
}
export declare namespace matchV4 {
    /**
     * MatchDto data object, automatically generated.
     */
    interface MatchDto {
        gameId: long;
        /** Participant identity information. */
        participantIdentities: matchV4.ParticipantIdentityDto[];
        /** Please refer to the Game Constants documentation. */
        queueId: int;
        /** Please refer to the Game Constants documentation. */
        gameType: string;
        /** Match duration in seconds. */
        gameDuration: long;
        /** Team information. */
        teams: matchV4.TeamStatsDto[];
        /** Platform where the match was played. */
        platformId: string;
        /** Designates the timestamp when champion select ended and the loading screen appeared, NOT when the game timer was at 0:00. */
        gameCreation: long;
        /** Please refer to the Game Constants documentation. */
        seasonId: int;
        /** The major.minor version typically indicates the patch the match was played on. */
        gameVersion: string;
        /** Please refer to the Game Constants documentation. */
        mapId: int;
        /** Please refer to the Game Constants documentation. */
        gameMode: string;
        /** Participant information. */
        participants: matchV4.ParticipantDto[];
    }
}
export declare namespace matchV4 {
    /**
     * ParticipantIdentityDto data object, automatically generated.
     */
    interface ParticipantIdentityDto {
        participantId: int;
        /** Player information not included in the response for custom matches. Custom matches are considered private unless a tournament code was used to create the match. */
        player: matchV4.PlayerDto;
    }
}
export declare namespace matchV4 {
    /**
     * PlayerDto data object, automatically generated.
     */
    interface PlayerDto {
        profileIcon: int;
        /** Player's original accountId (Encrypted) */
        accountId: string;
        matchHistoryUri: string;
        /** Player's current accountId (Encrypted) */
        currentAccountId: string;
        currentPlatformId: string;
        summonerName: string;
        /** Player's summonerId (Encrypted) */
        summonerId: string;
        /** Original platformId. */
        platformId: string;
    }
}
export declare namespace matchV4 {
    /**
     * TeamStatsDto data object, automatically generated.
     */
    interface TeamStatsDto {
        /** Number of towers the team destroyed. */
        towerKills: int;
        /** Number of times the team killed Rift Herald. */
        riftHeraldKills: int;
        /** Flag indicating whether or not the team scored the first blood. */
        firstBlood: boolean;
        /** Number of inhibitors the team destroyed. */
        inhibitorKills: int;
        /** If match queueId has a draft, contains banned champion data, otherwise empty. */
        bans: matchV4.TeamBansDto[];
        /** Flag indicating whether or not the team scored the first Baron kill. */
        firstBaron: boolean;
        /** Flag indicating whether or not the team scored the first Dragon kill. */
        firstDragon: boolean;
        /** For Dominion matches, specifies the points the team had at game end. */
        dominionVictoryScore: int;
        /** Number of times the team killed Dragon. */
        dragonKills: int;
        /** Number of times the team killed Baron. */
        baronKills: int;
        /** Flag indicating whether or not the team destroyed the first inhibitor. */
        firstInhibitor: boolean;
        /** Flag indicating whether or not the team destroyed the first tower. */
        firstTower: boolean;
        /** Number of times the team killed Vilemaw. */
        vilemawKills: int;
        /** Flag indicating whether or not the team scored the first Rift Herald kill. */
        firstRiftHerald: boolean;
        /** 100 for blue side. 200 for red side. */
        teamId: int;
        /** String indicating whether or not the team won. There are only two values visibile in public match history.
             (Legal values:  Fail,  Win) */
        win: "Fail" | "Win";
    }
}
export declare namespace matchV4 {
    /**
     * TeamBansDto data object, automatically generated.
     */
    interface TeamBansDto {
        /** Banned championId. */
        championId: int;
        /** Turn during which the champion was banned. */
        pickTurn: int;
    }
}
export declare namespace matchV4 {
    /**
     * ParticipantDto data object, automatically generated.
     */
    interface ParticipantDto {
        participantId: int;
        championId: int;
        /** List of legacy Rune information. Not included for matches played with Runes Reforged. */
        runes?: matchV4.RuneDto[] | null;
        /** Participant statistics. */
        stats: matchV4.ParticipantStatsDto;
        /** 100 for blue side. 200 for red side. */
        teamId: int;
        /** Participant timeline data. */
        timeline: matchV4.ParticipantTimelineDto;
        /** First Summoner Spell id. */
        spell1Id: int;
        /** Second Summoner Spell id. */
        spell2Id: int;
        /** Highest ranked tier achieved for the previous season in a specific subset of queueIds, if any, otherwise null. Used to display border in game loading screen. Please refer to the Ranked Info documentation.
             (Legal values:  CHALLENGER,  MASTER,  DIAMOND,  PLATINUM,  GOLD,  SILVER,  BRONZE,  UNRANKED) */
        highestAchievedSeasonTier?: "CHALLENGER" | "MASTER" | "DIAMOND" | "PLATINUM" | "GOLD" | "SILVER" | "BRONZE" | "UNRANKED" | null;
        /** List of legacy Mastery information. Not included for matches played with Runes Reforged. */
        masteries?: matchV4.MasteryDto[] | null;
    }
}
export declare namespace matchV4 {
    /**
     * RuneDto data object, automatically generated.
     */
    interface RuneDto {
        runeId: int;
        rank: int;
    }
}
export declare namespace matchV4 {
    /**
     * ParticipantStatsDto data object, automatically generated.
     */
    interface ParticipantStatsDto {
        item0: int;
        item2: int;
        totalUnitsHealed: int;
        item1: int;
        largestMultiKill: int;
        goldEarned: int;
        firstInhibitorKill?: boolean | null;
        physicalDamageTaken: long;
        nodeNeutralizeAssist?: int | null;
        totalPlayerScore?: int | null;
        champLevel: int;
        damageDealtToObjectives: long;
        totalDamageTaken: long;
        neutralMinionsKilled: int;
        deaths: int;
        tripleKills: int;
        magicDamageDealtToChampions: long;
        wardsKilled: int;
        pentaKills: int;
        damageSelfMitigated: long;
        largestCriticalStrike: int;
        nodeNeutralize?: int | null;
        totalTimeCrowdControlDealt: int;
        firstTowerKill?: boolean | null;
        magicDamageDealt: long;
        totalScoreRank?: int | null;
        nodeCapture?: int | null;
        wardsPlaced?: int | null;
        totalDamageDealt: long;
        timeCCingOthers: long;
        magicalDamageTaken: long;
        largestKillingSpree: int;
        totalDamageDealtToChampions: long;
        physicalDamageDealtToChampions: long;
        neutralMinionsKilledTeamJungle: int;
        totalMinionsKilled: int;
        firstInhibitorAssist?: boolean | null;
        visionWardsBoughtInGame: int;
        objectivePlayerScore?: int | null;
        kills: int;
        firstTowerAssist?: boolean | null;
        combatPlayerScore?: int | null;
        inhibitorKills?: int | null;
        turretKills?: int | null;
        participantId: int;
        trueDamageTaken: long;
        firstBloodAssist?: boolean | null;
        nodeCaptureAssist?: int | null;
        assists: int;
        teamObjective?: int | null;
        altarsNeutralized?: int | null;
        goldSpent: int;
        damageDealtToTurrets: long;
        altarsCaptured?: int | null;
        win: boolean;
        totalHeal: long;
        unrealKills: int;
        visionScore?: long | null;
        physicalDamageDealt: long;
        firstBloodKill?: boolean | null;
        longestTimeSpentLiving: int;
        killingSprees: int;
        sightWardsBoughtInGame?: int | null;
        trueDamageDealtToChampions: long;
        neutralMinionsKilledEnemyJungle: int;
        doubleKills: int;
        trueDamageDealt: long;
        quadraKills: int;
        item4: int;
        item3: int;
        item6: int;
        item5: int;
        playerScore0?: int | null;
        playerScore1?: int | null;
        playerScore2?: int | null;
        playerScore3?: int | null;
        playerScore4?: int | null;
        playerScore5?: int | null;
        playerScore6?: int | null;
        playerScore7?: int | null;
        playerScore8?: int | null;
        playerScore9?: int | null;
        /** Primary path keystone rune. */
        perk0?: int | null;
        /** Post game rune stats. */
        perk0Var1?: int | null;
        /** Post game rune stats. */
        perk0Var2?: int | null;
        /** Post game rune stats. */
        perk0Var3?: int | null;
        /** Primary path rune. */
        perk1?: int | null;
        /** Post game rune stats. */
        perk1Var1?: int | null;
        /** Post game rune stats. */
        perk1Var2?: int | null;
        /** Post game rune stats. */
        perk1Var3?: int | null;
        /** Primary path rune. */
        perk2?: int | null;
        /** Post game rune stats. */
        perk2Var1?: int | null;
        /** Post game rune stats. */
        perk2Var2?: int | null;
        /** Post game rune stats. */
        perk2Var3?: int | null;
        /** Primary path rune. */
        perk3?: int | null;
        /** Post game rune stats. */
        perk3Var1?: int | null;
        /** Post game rune stats. */
        perk3Var2?: int | null;
        /** Post game rune stats. */
        perk3Var3?: int | null;
        /** Secondary path rune. */
        perk4?: int | null;
        /** Post game rune stats. */
        perk4Var1?: int | null;
        /** Post game rune stats. */
        perk4Var2?: int | null;
        /** Post game rune stats. */
        perk4Var3?: int | null;
        /** Secondary path rune. */
        perk5?: int | null;
        /** Post game rune stats. */
        perk5Var1?: int | null;
        /** Post game rune stats. */
        perk5Var2?: int | null;
        /** Post game rune stats. */
        perk5Var3?: int | null;
        /** Primary rune path */
        perkPrimaryStyle?: int | null;
        /** Secondary rune path */
        perkSubStyle?: int | null;
    }
}
export declare namespace matchV4 {
    /**
     * ParticipantTimelineDto data object, automatically generated.
     */
    interface ParticipantTimelineDto {
        participantId?: int | null;
        /** Creep score difference versus the calculated lane opponent(s) for a specified period. */
        csDiffPerMinDeltas?: {
            [key: string]: double;
        } | null;
        /** Damage taken for a specified period. */
        damageTakenPerMinDeltas?: {
            [key: string]: double;
        } | null;
        /** Participant's calculated role.
             (Legal values:  DUO,  NONE,  SOLO,  DUO_CARRY,  DUO_SUPPORT) */
        role?: "DUO" | "NONE" | "SOLO" | "DUO_CARRY" | "DUO_SUPPORT" | null;
        /** Damage taken difference versus the calculated lane opponent(s) for a specified period. */
        damageTakenDiffPerMinDeltas?: {
            [key: string]: double;
        } | null;
        /** Experience change for a specified period. */
        xpPerMinDeltas?: {
            [key: string]: double;
        } | null;
        /** Experience difference versus the calculated lane opponent(s) for a specified period. */
        xpDiffPerMinDeltas?: {
            [key: string]: double;
        } | null;
        /** Participant's calculated lane. MID and BOT are legacy values.
             (Legal values:  MID,  MIDDLE,  TOP,  JUNGLE,  BOT,  BOTTOM) */
        lane?: "MID" | "MIDDLE" | "TOP" | "JUNGLE" | "BOT" | "BOTTOM" | null;
        /** Creeps for a specified period. */
        creepsPerMinDeltas?: {
            [key: string]: double;
        } | null;
        /** Gold for a specified period. */
        goldPerMinDeltas?: {
            [key: string]: double;
        } | null;
    }
}
export declare namespace matchV4 {
    /**
     * MasteryDto data object, automatically generated.
     */
    interface MasteryDto {
        rank: int;
        masteryId: int;
    }
}
export declare namespace matchV4 {
    /**
     * MatchlistDto data object, automatically generated.
     */
    interface MatchlistDto {
        startIndex: int;
        totalGames: int;
        endIndex: int;
        matches: matchV4.MatchReferenceDto[];
    }
}
export declare namespace matchV4 {
    /**
     * MatchReferenceDto data object, automatically generated.
     */
    interface MatchReferenceDto {
        gameId: long;
        role: string;
        season: int;
        platformId: string;
        champion: int;
        queue: int;
        lane: string;
        timestamp: long;
    }
}
export declare namespace matchV4 {
    /**
     * MatchTimelineDto data object, automatically generated.
     */
    interface MatchTimelineDto {
        frames: matchV4.MatchFrameDto[];
        frameInterval: long;
    }
}
export declare namespace matchV4 {
    /**
     * MatchFrameDto data object, automatically generated.
     */
    interface MatchFrameDto {
        participantFrames: {
            [key: string]: matchV4.MatchParticipantFrameDto;
        };
        events: matchV4.MatchEventDto[];
        timestamp: long;
    }
}
export declare namespace matchV4 {
    /**
     * MatchParticipantFrameDto data object, automatically generated.
     */
    interface MatchParticipantFrameDto {
        participantId: int;
        minionsKilled: int;
        teamScore?: int | null;
        dominionScore?: int | null;
        totalGold: int;
        level: int;
        xp: int;
        currentGold: int;
        position?: matchV4.MatchPositionDto | null;
        jungleMinionsKilled: int;
    }
}
export declare namespace matchV4 {
    /**
     * MatchPositionDto data object, automatically generated.
     */
    interface MatchPositionDto {
        x: int;
        y: int;
    }
}
export declare namespace matchV4 {
    /**
     * MatchEventDto data object, automatically generated.
     */
    interface MatchEventDto {
        laneType?: string | null;
        skillSlot?: int | null;
        ascendedType?: string | null;
        creatorId?: int | null;
        afterId?: int | null;
        eventType?: string | null;
        /** (Legal values:  CHAMPION_KILL,  WARD_PLACED,  WARD_KILL,  BUILDING_KILL,  ELITE_MONSTER_KILL,  ITEM_PURCHASED,  ITEM_SOLD,  ITEM_DESTROYED,  ITEM_UNDO,  SKILL_LEVEL_UP,  ASCENDED_EVENT,  CAPTURE_POINT,  PORO_KING_SUMMON) */
        type: "CHAMPION_KILL" | "WARD_PLACED" | "WARD_KILL" | "BUILDING_KILL" | "ELITE_MONSTER_KILL" | "ITEM_PURCHASED" | "ITEM_SOLD" | "ITEM_DESTROYED" | "ITEM_UNDO" | "SKILL_LEVEL_UP" | "ASCENDED_EVENT" | "CAPTURE_POINT" | "PORO_KING_SUMMON";
        levelUpType?: string | null;
        wardType?: string | null;
        participantId?: int | null;
        towerType?: string | null;
        itemId?: int | null;
        beforeId?: int | null;
        pointCaptured?: string | null;
        monsterType?: string | null;
        monsterSubType?: string | null;
        teamId?: int | null;
        position?: matchV4.MatchPositionDto | null;
        killerId?: int | null;
        timestamp: long;
        assistingParticipantIds?: int[] | null;
        buildingType?: string | null;
        victimId?: int | null;
    }
}
export declare namespace spectatorV4 {
    /**
     * CurrentGameInfo data object, automatically generated.
     */
    interface CurrentGameInfo {
        /** The ID of the game */
        gameId: long;
        /** The game type */
        gameType: string;
        /** The game start time represented in epoch milliseconds */
        gameStartTime: long;
        /** The ID of the map */
        mapId: long;
        /** The amount of time in seconds that has passed since the game started */
        gameLength: long;
        /** The ID of the platform on which the game is being played */
        platformId: string;
        /** The game mode */
        gameMode: string;
        /** Banned champion information */
        bannedChampions: spectatorV4.BannedChampion[];
        /** The queue type (queue types are documented on the Game Constants page) */
        gameQueueConfigId?: long | null;
        /** The observer information */
        observers: spectatorV4.Observer;
        /** The participant information */
        participants: spectatorV4.CurrentGameParticipant[];
    }
}
export declare namespace spectatorV4 {
    /**
     * BannedChampion data object, automatically generated.
     */
    interface BannedChampion {
        /** The turn during which the champion was banned */
        pickTurn: int;
        /** The ID of the banned champion */
        championId: long;
        /** The ID of the team that banned the champion */
        teamId: long;
    }
}
export declare namespace spectatorV4 {
    /**
     * Observer data object, automatically generated.
     */
    interface Observer {
        /** Key used to decrypt the spectator grid game data for playback */
        encryptionKey: string;
    }
}
export declare namespace spectatorV4 {
    /**
     * CurrentGameParticipant data object, automatically generated.
     */
    interface CurrentGameParticipant {
        /** The ID of the champion played by this participant */
        championId: long;
        /** Perks/Runes Reforged Information */
        perks: spectatorV4.Perks;
        /** The ID of the profile icon used by this participant */
        profileIconId: long;
        /** Flag indicating whether or not this participant is a bot */
        bot: boolean;
        /** The team ID of this participant, indicating the participant's team */
        teamId: long;
        /** The summoner name of this participant */
        summonerName: string;
        /** The encrypted summoner ID of this participant */
        summonerId: string;
        /** The ID of the first summoner spell used by this participant */
        spell1Id: long;
        /** The ID of the second summoner spell used by this participant */
        spell2Id: long;
        /** List of Game Customizations */
        gameCustomizationObjects: spectatorV4.GameCustomizationObject[];
    }
}
export declare namespace spectatorV4 {
    /**
     * Perks data object, automatically generated.
     */
    interface Perks {
        /** IDs of the perks/runes assigned. */
        perkIds: long[];
        /** Primary runes path */
        perkStyle: long;
        /** Secondary runes path */
        perkSubStyle: long;
    }
}
export declare namespace spectatorV4 {
    /**
     * GameCustomizationObject data object, automatically generated.
     */
    interface GameCustomizationObject {
        /** Category identifier for Game Customization */
        category: string;
        /** Game Customization content */
        content: string;
    }
}
export declare namespace spectatorV4 {
    /**
     * FeaturedGames data object, automatically generated.
     */
    interface FeaturedGames {
        /** The list of featured games */
        gameList: spectatorV4.FeaturedGameInfo[];
        /** The suggested interval to wait before requesting FeaturedGames again */
        clientRefreshInterval: long;
    }
}
export declare namespace spectatorV4 {
    /**
     * FeaturedGameInfo data object, automatically generated.
     */
    interface FeaturedGameInfo {
        /** The game mode
             (Legal values:  CLASSIC,  ODIN,  ARAM,  TUTORIAL,  ONEFORALL,  ASCENSION,  FIRSTBLOOD,  KINGPORO) */
        gameMode: "CLASSIC" | "ODIN" | "ARAM" | "TUTORIAL" | "ONEFORALL" | "ASCENSION" | "FIRSTBLOOD" | "KINGPORO";
        /** The amount of time in seconds that has passed since the game started */
        gameLength: long;
        /** The ID of the map */
        mapId: long;
        /** The game type
             (Legal values:  CUSTOM_GAME,  MATCHED_GAME,  TUTORIAL_GAME) */
        gameType: "CUSTOM_GAME" | "MATCHED_GAME" | "TUTORIAL_GAME";
        /** Banned champion information */
        bannedChampions: spectatorV4.BannedChampion[];
        /** The ID of the game */
        gameId: long;
        /** The observer information */
        observers: spectatorV4.Observer;
        /** The queue type (queue types are documented on the Game Constants page) */
        gameQueueConfigId: long;
        /** The game start time represented in epoch milliseconds */
        gameStartTime: long;
        /** The participant information */
        participants: spectatorV4.Participant[];
        /** The ID of the platform on which the game is being played */
        platformId: string;
    }
}
export declare namespace spectatorV4 {
    /**
     * Participant data object, automatically generated.
     */
    interface Participant {
        /** Flag indicating whether or not this participant is a bot */
        bot: boolean;
        /** The ID of the second summoner spell used by this participant */
        spell2Id: long;
        /** The ID of the profile icon used by this participant */
        profileIconId: long;
        /** The summoner name of this participant */
        summonerName: string;
        /** The ID of the champion played by this participant */
        championId: long;
        /** The team ID of this participant, indicating the participant's team */
        teamId: long;
        /** The ID of the first summoner spell used by this participant */
        spell1Id: long;
    }
}
export declare namespace summonerV4 {
    /**
     * SummonerDTO data object, automatically generated.
     * # Description
     * represents a summoner
     */
    interface SummonerDTO {
        /** Encrypted account ID. Max length 56 characters. */
        accountId: string;
        /** ID of the summoner icon associated with the summoner. */
        profileIconId: int;
        /** Date summoner was last modified specified as epoch milliseconds. The following events will update this timestamp: profile icon change, playing the tutorial or advanced tutorial, finishing a game, summoner name change */
        revisionDate: long;
        /** Summoner name. */
        name: string;
        /** Encrypted summoner ID. Max length 63 characters. */
        id: string;
        /** Encrypted PUUID. Exact length of 78 characters. */
        puuid: string;
        /** Summoner level associated with the summoner. */
        summonerLevel: long;
    }
}
export declare namespace tftLeagueV1 {
    /**
     * LeagueListDTO data object, automatically generated.
     */
    interface LeagueListDTO {
        leagueId: string;
        entries: tftLeagueV1.LeagueItemDTO[];
        tier: string;
        name: string;
        queue: string;
    }
}
export declare namespace tftLeagueV1 {
    /**
     * LeagueItemDTO data object, automatically generated.
     */
    interface LeagueItemDTO {
        freshBlood: boolean;
        /** First placement. */
        wins: int;
        summonerName: string;
        miniSeries?: tftLeagueV1.MiniSeriesDTO | null;
        inactive: boolean;
        veteran: boolean;
        hotStreak: boolean;
        rank: string;
        leaguePoints: int;
        /** Second through eighth placement. */
        losses: int;
        /** Player's encrypted summonerId. */
        summonerId: string;
    }
}
export declare namespace tftLeagueV1 {
    /**
     * MiniSeriesDTO data object, automatically generated.
     */
    interface MiniSeriesDTO {
        losses: int;
        progress: string;
        target: int;
        wins: int;
    }
}
export declare namespace tftLeagueV1 {
    /**
     * LeagueEntryDTO data object, automatically generated.
     */
    interface LeagueEntryDTO {
        leagueId: string;
        /** Player's encrypted summonerId. */
        summonerId: string;
        summonerName: string;
        queueType: string;
        tier: string;
        rank: string;
        leaguePoints: int;
        /** First placement. */
        wins: int;
        /** Second through eighth placement. */
        losses: int;
        hotStreak: boolean;
        veteran: boolean;
        freshBlood: boolean;
        inactive: boolean;
        miniSeries?: tftLeagueV1.MiniSeriesDTO | null;
    }
}
export declare namespace tftMatchV1 {
    /**
     * MatchDto data object, automatically generated.
     */
    interface MatchDto {
        /** Match metadata. */
        metadata: tftMatchV1.MetadataDto;
        /** Match info. */
        info: tftMatchV1.InfoDto;
    }
}
export declare namespace tftMatchV1 {
    /**
     * MetadataDto data object, automatically generated.
     */
    interface MetadataDto {
        /** Match data version. */
        data_version: string;
        /** Match id. */
        match_id: string;
        /** A list of encrypted participant PUUIDs. */
        participants: string[];
    }
}
export declare namespace tftMatchV1 {
    /**
     * InfoDto data object, automatically generated.
     */
    interface InfoDto {
        /** Unix timestamp. */
        game_datetime: long;
        /** Game length in seconds. */
        game_length: float;
        /** Game variation enum, i.e. "TFT3_GameVariation_BigLittleLegends", missing from official Riot API docs. */
        game_variation?: string | null;
        /** Game client version. */
        game_version: string;
        /** Participants. */
        participants: tftMatchV1.ParticipantDto[];
        /** Please refer to the League of Legends documentation. */
        queue_id: int;
        /** Teamfight Tactics set number. */
        tft_set_number: int;
    }
}
export declare namespace tftMatchV1 {
    /**
     * ParticipantDto data object, automatically generated.
     */
    interface ParticipantDto {
        /** Participant's companion. */
        companion: tftMatchV1.CompanionDto;
        /** Gold left after participant was eliminated. */
        gold_left: int;
        /** The round the participant was eliminated in. Note: If the player was eliminated in stage 2-1 their last_round would be 5. */
        last_round: int;
        /** Participant Little Legend level. Note: This is not the number of active units. */
        level: int;
        /** Participant placement upon elimination. */
        placement: int;
        /** Number of players the participant eliminated. */
        players_eliminated: int;
        /** Encrypted PUUID. */
        puuid: string;
        /** The number of seconds before the participant was eliminated. */
        time_eliminated: float;
        /** Damage the participant dealt to other players. */
        total_damage_to_players: int;
        /** A complete list of traits for the participant's active units. */
        traits: tftMatchV1.TraitDto[];
        /** A list of active units for the participant. */
        units: tftMatchV1.UnitDto[];
    }
}
export declare namespace tftMatchV1 {
    /**
     * TraitDto data object, automatically generated.
     */
    interface TraitDto {
        /** Trait name. */
        name: string;
        /** Number of units with this trait. */
        num_units: int;
        /** Current active tier for the trait. */
        tier_current: int;
        /** Total tiers for the trait. */
        tier_total?: int | null;
    }
}
export declare namespace tftMatchV1 {
    /**
     * UnitDto data object, automatically generated.
     */
    interface UnitDto {
        /** A list of the unit's items. Please refer to the Teamfight Tactics documentation for item ids. */
        items: int[];
        /** This field was introduced in patch 9.22 with data_version 2. */
        character_id: string;
        /** Unit name. */
        name: string;
        /** Unit rarity. This doesn't equate to the unit cost. */
        rarity: int;
        /** Unit tier. */
        tier: int;
    }
}
export declare namespace tftMatchV1 {
    /**
     * CompanionDto data object, automatically generated.
     */
    interface CompanionDto {
        skin_ID: int;
        content_ID: string;
        species: string;
    }
}
export declare namespace tftSummonerV1 {
    /**
     * SummonerDTO data object, automatically generated.
     * # Description
     * represents a summoner
     */
    interface SummonerDTO {
        /** ID of the summoner icon associated with the summoner. */
        profileIconId: int;
        /** Summoner name. */
        name: string;
        /** Encrypted PUUID. Exact length of 78 characters. */
        puuid: string;
        /** Summoner level associated with the summoner. */
        summonerLevel: long;
        /** Date summoner was last modified specified as epoch milliseconds. The following events will update this timestamp: profile icon change, playing the tutorial or advanced tutorial, finishing a game, summoner name change */
        revisionDate: long;
        /** Encrypted summoner ID. Max length 63 characters. */
        id: string;
        /** Encrypted account ID. Max length 56 characters. */
        accountId: string;
    }
}
export declare namespace tournamentStubV4 {
    /**
     * TournamentCodeParameters data object, automatically generated.
     */
    interface TournamentCodeParameters {
        /** Optional list of encrypted summonerIds in order to validate the players eligible to join the lobby. NOTE: We currently do not enforce participants at the team level, but rather the aggregate of teamOne and teamTwo. We may add the ability to enforce at the team level in the future. */
        allowedSummonerIds?: string[] | null;
        /** Optional string that may contain any data in any format, if specified at all. Used to denote any custom information about the game. */
        metadata?: string | null;
        /** The team size of the game. Valid values are 1-5. */
        teamSize: int;
        /** The pick type of the game.
             (Legal values:  BLIND_PICK,  DRAFT_MODE,  ALL_RANDOM,  TOURNAMENT_DRAFT) */
        pickType: "BLIND_PICK" | "DRAFT_MODE" | "ALL_RANDOM" | "TOURNAMENT_DRAFT";
        /** The map type of the game.
             (Legal values:  SUMMONERS_RIFT,  TWISTED_TREELINE,  HOWLING_ABYSS) */
        mapType: "SUMMONERS_RIFT" | "TWISTED_TREELINE" | "HOWLING_ABYSS";
        /** The spectator type of the game.
             (Legal values:  NONE,  LOBBYONLY,  ALL) */
        spectatorType: "NONE" | "LOBBYONLY" | "ALL";
    }
}
export declare namespace tournamentStubV4 {
    /**
     * LobbyEventDTOWrapper data object, automatically generated.
     */
    interface LobbyEventDTOWrapper {
        eventList: tournamentStubV4.LobbyEventDTO[];
    }
}
export declare namespace tournamentStubV4 {
    /**
     * LobbyEventDTO data object, automatically generated.
     */
    interface LobbyEventDTO {
        /** The summonerId that triggered the event (Encrypted) */
        summonerId: string;
        /** The type of event that was triggered */
        eventType: string;
        /** Timestamp from the event */
        timestamp: string;
    }
}
export declare namespace tournamentStubV4 {
    /**
     * ProviderRegistrationParameters data object, automatically generated.
     */
    interface ProviderRegistrationParameters {
        /** The region in which the provider will be running tournaments.
             (Legal values:  BR,  EUNE,  EUW,  JP,  LAN,  LAS,  NA,  OCE,  PBE,  RU,  TR) */
        region: "BR" | "EUNE" | "EUW" | "JP" | "LAN" | "LAS" | "NA" | "OCE" | "PBE" | "RU" | "TR";
        /** The provider's callback URL to which tournament game results in this region should be posted. The URL must be well-formed, use the http or https protocol, and use the default port for the protocol (http URLs must use port 80, https URLs must use port 443). */
        url: string;
    }
}
export declare namespace tournamentStubV4 {
    /**
     * TournamentRegistrationParameters data object, automatically generated.
     */
    interface TournamentRegistrationParameters {
        /** The provider ID to specify the regional registered provider data to associate this tournament. */
        providerId: int;
        /** The optional name of the tournament. */
        name?: string | null;
    }
}
export declare namespace tournamentV4 {
    /**
     * TournamentCodeParameters data object, automatically generated.
     */
    interface TournamentCodeParameters {
        /** Optional list of encrypted summonerIds in order to validate the players eligible to join the lobby. NOTE: We currently do not enforce participants at the team level, but rather the aggregate of teamOne and teamTwo. We may add the ability to enforce at the team level in the future. */
        allowedSummonerIds?: string[] | null;
        /** Optional string that may contain any data in any format, if specified at all. Used to denote any custom information about the game. */
        metadata?: string | null;
        /** The team size of the game. Valid values are 1-5. */
        teamSize: int;
        /** The pick type of the game.
             (Legal values:  BLIND_PICK,  DRAFT_MODE,  ALL_RANDOM,  TOURNAMENT_DRAFT) */
        pickType: "BLIND_PICK" | "DRAFT_MODE" | "ALL_RANDOM" | "TOURNAMENT_DRAFT";
        /** The map type of the game.
             (Legal values:  SUMMONERS_RIFT,  TWISTED_TREELINE,  HOWLING_ABYSS) */
        mapType: "SUMMONERS_RIFT" | "TWISTED_TREELINE" | "HOWLING_ABYSS";
        /** The spectator type of the game.
             (Legal values:  NONE,  LOBBYONLY,  ALL) */
        spectatorType: "NONE" | "LOBBYONLY" | "ALL";
    }
}
export declare namespace tournamentV4 {
    /**
     * TournamentCodeDTO data object, automatically generated.
     */
    interface TournamentCodeDTO {
        /** The tournament code. */
        code: string;
        /** The spectator mode for the tournament code game. */
        spectators: string;
        /** The lobby name for the tournament code game. */
        lobbyName: string;
        /** The metadata for tournament code. */
        metaData: string;
        /** The password for the tournament code game. */
        password: string;
        /** The team size for the tournament code game. */
        teamSize: int;
        /** The provider's ID. */
        providerId: int;
        /** The pick mode for tournament code game. */
        pickType: string;
        /** The tournament's ID. */
        tournamentId: int;
        /** The tournament code's ID. */
        id: int;
        /** The tournament code's region.
             (Legal values:  BR,  EUNE,  EUW,  JP,  LAN,  LAS,  NA,  OCE,  PBE,  RU,  TR) */
        region: "BR" | "EUNE" | "EUW" | "JP" | "LAN" | "LAS" | "NA" | "OCE" | "PBE" | "RU" | "TR";
        /** The game map for the tournament code game */
        map: string;
        /** The summonerIds of the participants (Encrypted) */
        participants: string[];
    }
}
export declare namespace tournamentV4 {
    /**
     * TournamentCodeUpdateParameters data object, automatically generated.
     */
    interface TournamentCodeUpdateParameters {
        /** Optional list of encrypted summonerIds in order to validate the players eligible to join the lobby. NOTE: We currently do not enforce participants at the team level, but rather the aggregate of teamOne and teamTwo. We may add the ability to enforce at the team level in the future. */
        allowedSummonerIds?: string[] | null;
        /** The pick type
             (Legal values:  BLIND_PICK,  DRAFT_MODE,  ALL_RANDOM,  TOURNAMENT_DRAFT) */
        pickType: "BLIND_PICK" | "DRAFT_MODE" | "ALL_RANDOM" | "TOURNAMENT_DRAFT";
        /** The map type
             (Legal values:  SUMMONERS_RIFT,  TWISTED_TREELINE,  HOWLING_ABYSS) */
        mapType: "SUMMONERS_RIFT" | "TWISTED_TREELINE" | "HOWLING_ABYSS";
        /** The spectator type
             (Legal values:  NONE,  LOBBYONLY,  ALL) */
        spectatorType: "NONE" | "LOBBYONLY" | "ALL";
    }
}
export declare namespace tournamentV4 {
    /**
     * LobbyEventDTOWrapper data object, automatically generated.
     */
    interface LobbyEventDTOWrapper {
        eventList: tournamentV4.LobbyEventDTO[];
    }
}
export declare namespace tournamentV4 {
    /**
     * LobbyEventDTO data object, automatically generated.
     */
    interface LobbyEventDTO {
        /** Timestamp from the event */
        timestamp: string;
        /** The type of event that was triggered */
        eventType: string;
        /** The summonerId that triggered the event (Encrypted) */
        summonerId: string;
    }
}
export declare namespace tournamentV4 {
    /**
     * ProviderRegistrationParameters data object, automatically generated.
     */
    interface ProviderRegistrationParameters {
        /** The region in which the provider will be running tournaments.
             (Legal values:  BR,  EUNE,  EUW,  JP,  LAN,  LAS,  NA,  OCE,  PBE,  RU,  TR) */
        region: "BR" | "EUNE" | "EUW" | "JP" | "LAN" | "LAS" | "NA" | "OCE" | "PBE" | "RU" | "TR";
        /** The provider's callback URL to which tournament game results in this region should be posted. The URL must be well-formed, use the http or https protocol, and use the default port for the protocol (http URLs must use port 80, https URLs must use port 443). */
        url: string;
    }
}
export declare namespace tournamentV4 {
    /**
     * TournamentRegistrationParameters data object, automatically generated.
     */
    interface TournamentRegistrationParameters {
        /** The provider ID to specify the regional registered provider data to associate this tournament. */
        providerId: int;
        /** The optional name of the tournament. */
        name?: string | null;
    }
}
